﻿using System;
using System.Collections.Generic;
using System.Text;

namespace TaskManager.Core
{
    /// <summary>
    /// 优先级决策要素
    /// </summary>
    [Serializable]
    public abstract class PriorityFactor
    {
        protected int p = 0;      // 权值
        protected int v = 1;      // 值
        protected string name;    // 要素名字

        public string Name
        {
            get { return name; }
            set { if (name != string.Empty && name != null) name = value; }
        }

        protected PriorityFactor(string name, int p)
        {
            if (name == null || name == string.Empty ||
                p < 1 || p > 5)
                throw new ArgumentException();

            this.name = name;
            this.p = p;
        }

        /// <summary>
        /// 获取权值。
        /// </summary>
        /// <returns>权值。</returns>
        public int GetP()
        {
            return p;
        }

        /// <summary>
        /// 获取值。
        /// </summary>
        /// <returns>值。</returns>
        public abstract int GetV();

        /// <summary>
        /// 设置值。派生类重写此方法时要进行参数检查。
        /// </summary>
        /// <param name="value">要设置的值，范围为[1,5]。</param>
        public abstract void SetV(int value);

        public override int GetHashCode()
        {
            return p ^ v ^ name.Length;
        }

        public override bool Equals(object obj)
        {
            if (object.Equals(obj, null)) return base.Equals(obj);
            if (!(obj is PriorityFactor)) return false;
            PriorityFactor other = obj as PriorityFactor;
            if (other.name == this.name &&
                other.p == this.p &&
                other.v == this.v) return true;
            return false;
        }

        public override string ToString()
        {
            return name + "，权值：" + p + " 值：" + v;
        }
    }
}
