﻿using System;
using System.Collections.Generic;
using System.Text;

namespace TaskManager.Core
{
    [Serializable]
    public class Task
    {
        private string name;
        private Dictionary<string, PriorityFactor> factors;
        private string guid;

        public string Name
        {
            get { return name; }
            set { if (value != null) name = value; }
        }

        public string Guid
        {
            get { return guid; }
        }

        public Dictionary<string, PriorityFactor> Factors
        {
            get { return factors; }
        }

        public Task(string name)
        {
            if (name == null) throw new ArgumentNullException();

            this.guid = System.Guid.NewGuid().ToString();
            this.name = name;
            this.factors = PriorityFactorsAssemblier.Create();
        }

        public Task(string guid, string name)
        {
            if (guid == null || name == null) throw new ArgumentNullException();

            this.guid = guid;
            this.name = name;
            this.factors = PriorityFactorsAssemblier.Create();
        }

        public override bool Equals(object obj)
        {
            if (object.Equals(obj, null)) return base.Equals(obj);
            if (!(obj is Task)) return false;
            Task other = obj as Task;
            if (other.guid == this.guid) return true;
            return false;
        }

        public override int GetHashCode()
        {
            return guid.GetHashCode() ^ name.GetHashCode();
        }

        public override string ToString()
        {
            return name;
        }
    }
}
