﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Collections;

namespace TaskManager.Core
{
    [Serializable]
    public class TaskList : IEnumerable
    {
        private List<Task> tasks;

        public TaskList()
        {
            tasks = new List<Task>();
        }

        public Task this[int index]
        {
            get { return tasks[index]; }
        }

        public int Count
        {
            get { return tasks.Count; }
        }

        public void Append(Task task)
        {
            tasks.Add(task);
        }

        public void Delete(int index)
        {
            Task task = tasks[index];
            tasks.RemoveAt(index);
        }

        public void Sort()
        {
            tasks.Sort(new Comparer());
        }

        private class Comparer : IComparer<Task>
        {
            #region IComparer<Task> 成员

            public int Compare(Task x, Task y)
            {
                PriorityCalculator calx = new PriorityCalculator(x);
                PriorityCalculator caly = new PriorityCalculator(y);
                double ret = caly.Calculate() - calx.Calculate();
                if (ret > 0) return 1;
                if (ret == 0) return 0;
                return -1;
            }

            #endregion
        }

        #region IEnumerable 成员

        public IEnumerator GetEnumerator()
        {
            return ((IEnumerable)tasks).GetEnumerator();
        }

        #endregion
    }
}
