﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using TaskManager.Core;
using System.Xml.XPath;
using System.Reflection;

namespace TaskManager.DB
{
    class XmlTaskListsReader : ITaskListsReader
    {
        private XmlTaskListsContext context;

        public XmlTaskListsReader(XmlTaskListsContext context)
        {
            this.context = context;
        }

        #region ITaskListsReader 成员

        public List<TaskManager.Core.TaskList> Read()
        {
            List<TaskList> taskLists = new List<TaskList>();

            XPathDocument xml = new XPathDocument(context.GetXmlFileName());
            XPathNavigator navigator = xml.CreateNavigator();
            try
            {
                XPathNodeIterator taskListNodeItr = navigator.Select("/TaskManager/TaskList");
                while (taskListNodeItr.MoveNext())
                {
                    TaskList taskList = new TaskList();
                    XPathNodeIterator taskNodeItr =
                        taskListNodeItr.Current.CreateNavigator().SelectChildren("Task", "");
                    while (taskNodeItr.MoveNext())
                    {
                        string guid = taskNodeItr.Current.GetAttribute("guid", "");
                        string name = taskNodeItr.Current.GetAttribute("name", "");
                        int imp = int.Parse(taskNodeItr.Current.GetAttribute("imp", ""));
                        int urg = int.Parse(taskNodeItr.Current.GetAttribute("urg", ""));
                        int tim = int.Parse(taskNodeItr.Current.GetAttribute("tim", ""));
                        int res = int.Parse(taskNodeItr.Current.GetAttribute("res", ""));
                        int tec = int.Parse(taskNodeItr.Current.GetAttribute("tec", ""));
                        
                        Task task = new Task(guid, name);
                        task.Factors["imp"].SetV(imp);
                        task.Factors["urg"].SetV(urg);
                        task.Factors["tim"].SetV(tim);
                        task.Factors["res"].SetV(res);
                        task.Factors["tec"].SetV(tec);

                        taskList.Append(task);
                    }
                    taskLists.Add(taskList);
                }
            }
            catch (Exception ex)
            {
                throw new FileCorruptedException("数据文件损坏", ex);
            }

            return taskLists;
        }

        #endregion
    }
}
