﻿#if DEBUG

using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using TaskManager.DB;
using TaskManager.Core;
using System.IO;

namespace TaskManager.Tests
{
    [TestFixture]
    public class XmlTaskListsReaderTests
    {
        [Test]
        public void ReadXml()
        {
            using (StreamWriter writer = new StreamWriter(XmlTaskListsContext.Instance.GetXmlFileName()))
            {
                string xml = @"<?xml version=""1.0"" encoding=""utf-8"" ?>
<TaskManager>
	<TaskList>
		<Task guid=""e4c7aa2a-b0fc-4f7a-80c2-99f1c51a0883"" name=""testTask1"" imp=""2"" urg=""1"" tim=""1"" res=""1"" tec=""1""></Task>
	</TaskList>
</TaskManager>
";
                writer.Write(xml);
            }

            XmlTaskListsReader reader = XmlTaskListsReaderFactory.Create();
            List<TaskList> taskLists = reader.Read();

            Assert.IsNotNull(taskLists);
            Assert.AreEqual(1, taskLists.Count);
            for (int i = 0; i < taskLists.Count; i++)
            {
                TaskList taskList = taskLists[i];
                for (int j = 0; j < taskList.Count; j++)
                {
                    Assert.AreEqual("e4c7aa2a-b0fc-4f7a-80c2-99f1c51a0883", taskList[j].Guid);
                    Assert.AreEqual("testTask1", taskList[j].Name);
                    Assert.AreEqual(2, taskList[j].Factors["imp"].GetV());
                    Assert.AreEqual(1, taskList[j].Factors["urg"].GetV());
                    Assert.AreEqual(1, taskList[j].Factors["tim"].GetV());
                    Assert.AreEqual(1, taskList[j].Factors["res"].GetV());
                    Assert.AreEqual(1, taskList[j].Factors["tec"].GetV());
                }
            }
        }
    }
}

#endif